@@ -99,13 +99,9 @@
 #'
 #' # Variable Selectioin Based on LASSO
 #' res_varSel_LASSO = plsim.vs.hard(xdat=X,zdat=Z,ydat=y,h=0.1,Method="LASSO")
-
+#' 
 plsim.vs.hard = function(...)
 {
-  args = list(...)
-  if (is(args[[1]],"formula"))
-    UseMethod("plsim.vs.hard",args[[1]])
-  else
     UseMethod("plsim.vs.hard")
 }
 
@@ -115,7 +111,6 @@ plsim.vs.hard.formula = function(formula,data,...)
   m = match(c("formula","data"),
             names(mf), nomatch = 0) 
   mf = mf[c(1,m)]
-  
   mf.xf = mf
   
   mf[[1]] = as.name("model.frame")
@@ -124,7 +119,7 @@ plsim.vs.hard.formula = function(formula,data,...)
   chromoly = deal_formula(mf[["formula"]])
   
   if (length(chromoly) != 3)
-    stop("invoked with improper formula, please see plsim.vs.hard documentation for proper use")
+    stop("Invoked with improper formula, please see plsim.est documentation for proper use")
   
   bronze = lapply(chromoly, paste, collapse = " + ")
   
@@ -134,6 +129,7 @@ plsim.vs.hard.formula = function(formula,data,...)
   mf[["formula"]] = as.formula(paste(bronze[[1]]," ~ ", bronze[[3]]),
                                env = environment(formula))
   
+  
   formula.all = terms(as.formula(paste(" ~ ",bronze[[1]]," + ",bronze[[2]], " + ",bronze[[3]]),
                                  env = environment(formula)))
   
@@ -144,52 +140,43 @@ plsim.vs.hard.formula = function(formula,data,...)
   arguments.mfx = chromoly[[2]]
   arguments.mf = c(chromoly[[1]],chromoly[[3]])
   
-  
   mf[["formula"]] = terms(mf[["formula"]])
   mf.xf[["formula"]] = terms(mf.xf[["formula"]])
   
-  if(all(orig.class == "ts")){
-    arguments = (as.list(attr(formula.all, "variables"))[-1])
-    attr(mf[["formula"]], "predvars") = bquote(.(as.call(c(quote(as.data.frame),as.call(c(quote(ts.intersect), arguments)))))[,.(match(arguments.mf,arguments)),drop = FALSE])
-    attr(mf.xf[["formula"]], "predvars") = bquote(.(as.call(c(quote(as.data.frame),as.call(c(quote(ts.intersect), arguments)))))[,.(match(arguments.mfx,arguments)),drop = FALSE])
-  }else if(any(orig.class == "ts")){
-    arguments = (as.list(attr(formula.all, "variables"))[-1])
-    arguments.normal = arguments[which(orig.class != "ts")]
-    arguments.timeseries = arguments[which(orig.class == "ts")]
-    
-    ix = sort(c(which(orig.class == "ts"),which(orig.class != "ts")),index.return = TRUE)$ix
-    attr(mf[["formula"]], "predvars") = bquote((.(as.call(c(quote(cbind),as.call(c(quote(as.data.frame),as.call(c(quote(ts.intersect), arguments.timeseries)))),arguments.normal,check.rows = TRUE)))[,.(ix)])[,.(match(arguments.mf,arguments)),drop = FALSE])
-    attr(mf.xf[["formula"]], "predvars") = bquote((.(as.call(c(quote(cbind),as.call(c(quote(as.data.frame),as.call(c(quote(ts.intersect), arguments.timeseries)))),arguments.normal,check.rows = TRUE)))[,.(ix)])[,.(match(arguments.mfx,arguments)),drop = FALSE])
-  }
-  
-  
   mf = tryCatch({
     eval(mf,parent.frame())
   },error = function(e){
     NULL
   })
   
+  temp = map_lgl(mf , ~is.factor(.x))
+  if(sum(temp)>0){
+    stop("Categorical variables are not allowed in Z or Y")
+  }
+  
   mf.xf = tryCatch({
     eval(mf.xf,parent.frame())
   },error = function(e){
     NULL
   })
   
+  mt <- attr(mf.xf, "terms")
+  
   if(is.null(mf)){
-    cat( blue$bold("\n Z (")
-         %+% black$bold("z")
-         %+% blue$bold(") should not be NULL.\n")
-         %+% blue$bold(" If Z is null, please utilize linear models, such as ")
-         %+% black$bold("lm() ")
-         %+% blue$bold("function. \n\n")
-    )
-    return(NULL)
+    stop("Z should not be NULL")
   }
   else{
     ydat = model.response(mf)
   }
   
-  xdat = mf.xf
+  if(!is.null(mf.xf))
+  {
+    xdat = model.matrix(mt, mf.xf, NULL)
+    xdat = as.matrix(xdat[,2:dim(xdat)[2]])
+  }else{
+    xdat = mf.xf
+  }
+  
   zdat = mf[, chromoly[[3]], drop = FALSE]
   
   ydat = data.matrix(ydat)
@@ -225,7 +212,19 @@ plsim.vs.hard.default = function(xdat=NULL,zdat,ydat,h=NULL,zeta_i=NULL,lambdaLi
   y = data$y
   z = data$z
   
-  if ( is.null( .assertion_for_variables(data)) ) return(NULL)
+  .assertion_for_variables(data)
+  
+  tempz = map_lgl(z , ~is.factor(.x))
+  tempy = map_lgl(y , ~is.factor(.x))
+  if((sum(tempz)>0)|(sum(tempy)>0)){
+    stop("Categorical variables are not allowed in Z or Y")
+  }
+  
+  if(!is.null(x)){
+    x = model.matrix(~., as.data.frame(x))
+    x = as.matrix(x[,2:dim(x)[2]])
+  }
+  
   
   if(is.data.frame(x))
     x = data.matrix(x)
@@ -256,9 +255,6 @@ plsim.vs.hard.default = function(xdat=NULL,zdat,ydat,h=NULL,zeta_i=NULL,lambdaLi
     class(data) = 'PPLSE'
   }
   
-  #cat("\n ")
-  #cat( blue$bold(Method) )
-  #cat(" \n")
   
   if( !is.null(h) & length(h)==1 )
   {
@@ -277,9 +273,8 @@ plsim.vs.hard.default = function(xdat=NULL,zdat,ydat,h=NULL,zeta_i=NULL,lambdaLi
     {
       if(verbose)
       {
-        cat( blue$bold("\n----------Variable Selection when h=")
-             %+% blue$bold(as.character(hVec[j]))
-             %+% blue$bold("----------\n\n") )        
+        cat(paste("\n----------Variable Selection when h=",
+                  as.character(hVec[j]),"----------\n\n",sep=""))        
       }
       
       
@@ -289,7 +284,7 @@ plsim.vs.hard.default = function(xdat=NULL,zdat,ydat,h=NULL,zeta_i=NULL,lambdaLi
       
       if(verbose)
       {
-        cat( "BIC: "%+%blue$bold(as.character(res_tmp$fit_plsimest$BIC)))        
+        cat( paste("BIC: ",as.character(res_tmp$fit_plsimest$BIC),"\n", sep=""))        
       }
       
       
@@ -303,7 +298,6 @@ plsim.vs.hard.default = function(xdat=NULL,zdat,ydat,h=NULL,zeta_i=NULL,lambdaLi
   }
   else if( is.null(h) )
   {
-    #hVec = c(0.01,0.02,0.05,0.1,0.5)
     
     hVec = seq(0.1/sqrt(n),2*sqrt(log(n)/n),length=20)
     
@@ -314,9 +308,8 @@ plsim.vs.hard.default = function(xdat=NULL,zdat,ydat,h=NULL,zeta_i=NULL,lambdaLi
     {
       if(verbose)
       {
-        cat( blue$bold("\n----------Variable Selection when h=")
-             %+% blue$bold(as.character(hVec[j]))
-             %+% blue$bold("----------\n\n") )        
+        cat(paste("\n----------Variable Selection when h=",
+                  as.character(hVec[j]),"----------\n\n"), sep="")      
       }
       
       
@@ -328,7 +321,7 @@ plsim.vs.hard.default = function(xdat=NULL,zdat,ydat,h=NULL,zeta_i=NULL,lambdaLi
       
       if(verbose)
       {
-        cat( " BIC: "%+%blue$bold(as.character(res_tmp$fit_plsimest$BIC)))
+        cat( paste(" BIC: ",as.character(res_tmp$fit_plsimest$BIC),sep=""))
         cat("\n")        
       }
       
@@ -355,7 +348,7 @@ varSelCore=function(data,h,zeta_i,verbose,lambdaList,l1RatioList,
 }
 
 varSelCore.PPLSE=function(data,h,zeta_i,verbose,lambdaList,l1RatioList,
-                          lambda_selector,threshold,Method,flag,ParmaSelMethod,seed,...)
+                          lambda_selector,threshold,Method,flag,ParmaSelMethod,seed)
 {
   
   
@@ -422,8 +415,8 @@ varSelCore.PPLSE=function(data,h,zeta_i,verbose,lambdaList,l1RatioList,
   
   if(verbose)
   {
-    cat( blue$bold("\n Important varaibles in Z are")
-         ,paste(black$bold(alpha_varSel),collapse = ","),sep = ": ")    
+    cat(paste("\n Important varaibles in Z are",
+        paste(alpha_varSel,collapse = ","),sep = ": "))    
   }
   
   if(!is.null(x))
@@ -432,8 +425,8 @@ varSelCore.PPLSE=function(data,h,zeta_i,verbose,lambdaList,l1RatioList,
     {
       if(verbose)
       {
-        cat(blue$bold("\n Important varaibles in X are"),
-            paste(black$bold(beta_varSel),collapse = ","),sep = ": ")        
+        cat(paste("\n Important varaibles in X are",
+                  paste(beta_varSel,collapse = ","),sep = ": "))        
       }
       
     }
@@ -553,7 +546,6 @@ varSelCore.StepWise=function(data,h,zeta_i,verbose,lambdaList,l1RatioList,
       }      
     }
     
-    #cat(res$alpha_varSel)
     if(length(res$alpha_varSel) > 1)
     {
       z_vs = z[,res$alpha_varSel]
@@ -612,9 +604,6 @@ stepWise=function(data,h,zeta_i,Method="BIC",seed,verbose)
   while (TRUE)
   {
     
-    #cat( paste(Method,IC_all,sep = ':'))
-    #cat('\n')
-    
     res = dropOneVar(x,y,z,h,zeta_i,Method,seed)
     IC_tmp = res$IC
     Component = res$Component
@@ -679,8 +668,6 @@ stepWise=function(data,h,zeta_i,Method="BIC",seed,verbose)
     
   }
   
-  
-  
   result = list()
   if(!is.null(x))
   {
@@ -774,7 +761,6 @@ dropOneVar=function(x,y,z,h,zeta_i,Method="BIC",seed)
     
     zeta_tmp = zeta_i[-i]
     
-    #data_tmp = list(x=x,z=z_tmp,y=y)
     res = plsim.est(x,z_tmp,y,h,zeta_tmp,seed=seed)
     zeta = res$zeta
     mse = res$mse
@@ -808,71 +794,6 @@ dropOneVar=function(x,y,z,h,zeta_i,Method="BIC",seed)
     result$Idx = Z_IC_min_Idx
   }
   
-  class(result) = "pls"
   
   return(result)
-}
-
-#varSel=function(x,z,y,h,zeta_i=NULL,lambdaList=NULL,
-#                l1RatioList=NULL,lambda_selector="BIC",threshold=0.05,
-#                Method="SCAD",verbose=TRUE
-#                )
-#{
-#  data = list(x=x,y=y,z=z)
-
-#  if ( is.null( .assertion_for_variables(data)) ) return(NULL)
-
-#  if(is.null(zeta_i))
-#  {
-#    zeta_i = plsim.ini(x,z,y)
-#  }    
-
-
-#  if(Method %in% c('SCAD','LASSO','ElasticNet') )
-#  {
-#    class(data) = 'PPLSE'  
-#  }
-#  else if(Method %in% c('AIC','BIC') )
-#  {
-#    class(data) = 'StepWise'
-#  }
-#  else
-#  {
-#    Method = "SCAD"
-#    class(data) = 'PPLSE'
-#  }
-
-#  cat("\n ")
-#  cat( blue$bold(Method) )
-#  cat(" \n")
-
-
-#  varSelCore(data,h,zeta_i,verbose,lambdaList,l1RatioList,lambda_selector,threshold,Method)
-#}
-
-
-# 
-# varSel.AIC=function(data,h,zeta_i,verbose=TRUE,lambdaList=vector(length=0),
-#                     l1RatioList=NULL,lambda_selector="BIC",threshold=1e-3)
-# {
-# 
-#   if ( is.null( .assertion_for_variables(data)) ) return(NULL)
-# 
-#   cat(blue$bold("\n AIC \n"))
-# 
-#   res = stepWise(data,h,zeta_i,"AIC")
-# 
-#   return(res)
-# }
-# 
-# varSel.BIC=function(data,h,zeta_i,verbose=TRUE,lambdaList=vector(length=0),
-#                     l1RatioList=NULL,lambda_selector="BIC",threshold=1e-3)
-# {
-#   if ( is.null( .assertion_for_variables(data)) ) return(NULL)
-# 
-#   cat(blue$bold("\n BIC \n"))
-# 
-#   res = stepWise(data,h,zeta_i,"BIC")
-# 
-#   return(res)
-# }
\ No newline at end of file
+}
\ No newline at end of file
